/*
alphamaskshader.glsl
fragment shader

Renders fragments fully transparent when their alpha value is equal to or lesser
than threshold (1 - vertex alpha).
Above, they're faded to fully opaque.
*/

// Texture to render
uniform sampler2D ColorTexture;

// Sharpness of alpha fade
uniform float Sharpness;

void shader(){
	// source color
	vec4 frag = texture2D( ColorTexture, b3d_Texcoord0 );
	// apply vertex color, and undo pre-multiplication
	frag.rgb *= b3d_Color.rgb / b3d_Color.a / frag.a;
	
	// threshold (> is opaque)
	float th = 1.0 - b3d_Color.a;
	
	// mask
	// clamping is necessary to prevent glitches with vertex colouring
	float alpha = clamp((frag.a - th) * Sharpness, 0.0, 1.0);

	// write output
	b3d_FragColor = vec4( frag.rgb * alpha, alpha );
}
