/*
staticredmaskshader.glsl
fragment shader

Renders fragments fully transparent when the mask's red value is equal to or
lesser than Threshold.
Above, they're faded to fully opaque.
*/

// Texture to render
uniform sampler2D ColorTexture;
// Mask
uniform sampler2D Mask;

// Threshold (where alpha = threshold fragments will be fully transparent)
uniform float Threshold;
// Sharpness of alpha fade
uniform float Sharpness;

void shader(){
	// source color
	vec4 frag = texture2D( ColorTexture, b3d_Texcoord0 );
	// apply vertex color, and undo pre-multiplication
	frag.rgb *= b3d_Color.rgb / b3d_Color.a / frag.a;
	
	// mask value
	float ma = texture2D( Mask, b3d_Texcoord0 ).r;
	// mask
	// clamping is necessary to prevent glitches with vertex colouring
	float alpha = clamp((ma - Threshold) * Sharpness, 0.0, 1.0);
	// apply fragment and vertex alpha
	alpha *= frag.a * b3d_Color.a;

	// write output
	b3d_FragColor = vec4( frag.rgb * alpha, alpha );
}
